@@ -7,3 +7,5 @@ pp <- function(fitted, ...)
   UseMethod("pp")
 dens <- function(fitted, ...)
   UseMethod("dens")
+convassess <- function(fitted, n = 50)
+  UseMethod("convassess")
